@@ -1,14 +1,21 @@
-""" Package for computing dice probabilities. """
+""" Package for computing dice probabilities.
+
+See [this JupyterLite distribution](https://highdiceroller.gitlab.io/hdroller/notebooks/lab/index.html) for examples.
+
+[Visit the project page.](https://gitlab.com/highdiceroller/hdroller)
+"""
 
 __docformat__ = 'google'
 
 # Expose certain names at top-level.
 
-from hdroller.die.func import Die, standard, d, __getattr__, bernoulli, coin, from_cweights, from_sweights, from_rv, mix, align, align_range, check_ndim, apply
+from hdroller.die.create import Die, dice_with_common_ndim
+from hdroller.die.func import standard, d, __getattr__, bernoulli, coin, from_cweights, from_sweights, from_rv, align, align_range, apply
 
 import hdroller.die.base
 
 from hdroller.die.base import BaseDie
+from hdroller.die.empty import EmptyDie
 from hdroller.die.scalar import ScalarDie
 from hdroller.die.vector import VectorDie
 
@@ -27,11 +34,12 @@ class SpecialValue(enum.Enum):
 
 Reroll = SpecialValue.Reroll
 
-__all__ = ['Die', 'standard', 'd', '__getattr__', 'bernoulli', 'coin',
-    'BaseDie', 'ScalarDie', 'VectorDie',
-    'from_cweights', 'from_sweights', 'from_rv', 'mix', 'align', 'align_range', 'check_ndim',
+__all__ = ['Die',
+    'standard', 'd', '__getattr__', 'bernoulli', 'coin',
+    'BaseDie', 'EmptyDie', 'ScalarDie', 'VectorDie',
+    'from_cweights', 'from_sweights', 'from_rv', 'align', 'align_range',
     'lowest', 'highest', 'max_outcome', 'min_outcome',
-    'apply',
+    'apply', 'dice_with_common_ndim',
     'Reroll',
     'Pool', 'standard_pool', 'DicePool',
     'EvalPool', 'WrapFuncEval', 'SumPool', 'sum_pool', 'FindBestSet', 'FindBestRun',
