@@ -60,12 +60,16 @@ class Weights():
     
     def items(self):
         return self._items
-    
-    def __len__(self):
-        return len(self._d)
 
     def __str__(self):
         return str(self._d)
     
     def __repr__(self):
-        return type(self).__qualname__ + f'({repr(self._d)})'
\ No newline at end of file
+        return type(self).__qualname__ + f'({repr(self._d)})'
+
+class Slicer():
+    def __init__(self, bound_func):
+        self._func = bound_func
+
+    def __getitem__(self, select):
+        return self._func(select)
\ No newline at end of file
