@@ -7,10 +7,7 @@ from functools import cached_property
 import math
 
 def Pool(die, num_dice=None, count_dice=None, *, max_outcomes=None, min_outcomes=None):
-    """ Factory function for dice pools.
-    
-    A pool represents rolling a set of dice where you do not know which die rolled which outcome,
-    only how many dice rolled each outcome.
+    """ Factory function for `DicePool`.
     
     This should be used in conjunction with `EvalPool` to generate a result.
     
@@ -167,8 +164,15 @@ def count_dice_tuple(num_dice, count_dice):
         else:
             # Ellipsis in center.
             if extra_dice < 0:
-                raise ValueError(f'count_dice={count_dice} with Ellipsis (...) in center has too many elements for num_dice={num_dice}.')
-            return tuple(count_dice[:split]) + (0,) * extra_dice + tuple(count_dice[split+1:])
+                result = [0] * num_dice
+                for i in range(min(split, num_dice)):
+                    result[i] += count_dice[i]
+                reverse_split = split - len(count_dice)
+                for i in range(-1, max(reverse_split - 1, -num_dice - 1), -1):
+                    result[i] += count_dice[i]
+                return tuple(result)
+            else:
+                return tuple(count_dice[:split]) + (0,) * extra_dice + tuple(count_dice[split+1:])
 
 _pool_cache = {}
 
@@ -204,6 +208,18 @@ def standard_pool(*die_sizes, count_dice=None):
     return Pool(hdroller.d(max(die_sizes)), count_dice=count_dice, max_outcomes=die_sizes)
 
 class DicePool():
+    """ A pool is a set of (semi-)identical dice that are rolled in no particular order
+    and sorted only after the fact.
+    
+    A pool is defined by:
+
+    * A fundamental die.
+    * The number of dice in the pool.
+    * Which of the sorted positions are counted (possibly multiple or negative times).
+    * Possibly limiting the max or min outcomes of dice in the pool (but not both)
+        relative to the fundamental die.
+    """
+    
     def __init__(self, die, count_dice, *, max_outcomes, min_outcomes):
         """ Unchecked constructor.
         
@@ -255,15 +271,28 @@ class DicePool():
             A sequence of one `int`s for each die.
                 Each die is counted that many times, which could be multiple or negative times.
                 This may resize the pool, but only if the pool does not have `max_outcomes` or `min_outcomes`.
+                
                 Up to one `Ellipsis` (`...`) may be used.
-                If one is used, `count_dice` will be padded with zero counts if shorter than `num_dice`,
-                or trimmed if longer.
+                If an `Ellipsis` is used, the size of the pool won't change. Instead:
+                
+                * If `count_dice` is shorter than `num_dice`, the `Ellipsis`
+                    acts as enough zero counts to make up the difference.
+                    For example, `pool[1, ..., 1]` on five dice would act as `pool[1, 0, 0, 0, 1]`.
+                * If `count_dice` has length equal to `num_dice`, the `Ellipsis` has no effect.
+                    For example, `pool[1, ..., 1]` on two dice would act as `pool[1, 1]`.
+                * If `count_dice` is longer than `num_dice` and the `Ellipsis` is on one side,
+                    elements will be dropped from `count_dice` on the side with the `Ellipsis`.
+                    For example, `pool[..., 1, 2, 3]` on two dice would act as `pool[2, 3]`.
+                * If `count_dice` is longer than `num_dice` and the `Ellipsis` is in the middle,
+                    the counts will be as the sum of two one-sided `Ellipsis`.
+                    For example, `pool[-1, ..., 1]` acts like `[-1, ...]` plus `[..., 1]`.
+                    On a pool consisting of a single single die this would have the -1 and 1 cancel each other out.
         
         Raises:
-            ValueError if:
-                * `count_dice` would change the size of a pool with `max_outcomes` or `min_outcomes`.
-                * More than one `Ellipsis` is used.
-                * `Ellipsis` is used in the center with too many elements for `num_dice`.
+            ValueError:
+            
+                * If `count_dice` would change the size of a pool with `max_outcomes` or `min_outcomes`.
+                * If more than one `Ellipsis` is used.
         
         For example, here are some ways of selecting the two highest dice out of 5:
         
@@ -325,7 +354,7 @@ class DicePool():
         """ A tuple of sorted max outcomes, one for each die in the pool. 
         
         Args:
-            * always_tuple: If `False`, this will return `None` if there are no die-specific max_outcomes.
+            always_tuple: If `False`, this will return `None` if there are no die-specific `max_outcomes`.
                 If `True` this will return a `tuple` even in this case.
         """
         if self._max_outcomes is None and always_tuple:
@@ -336,7 +365,7 @@ class DicePool():
         """ A tuple of sorted min outcomes, one for each die in the pool. 
         
         Args:
-            * always_tuple: If `False`, this will return `None` if there are no die-specific min_outcomes.
+            always_tuple: If `False`, this will return `None` if there are no die-specific `min_outcomes`.
                 If `True` this will return a `tuple` even in this case.
         """
         if self._min_outcomes is None and always_tuple:
@@ -389,7 +418,7 @@ class DicePool():
             # We empty the rest of the pool immediately since no more dice can contribute counts.
             skip_weight = 0
             for weight in comb_row[end_counted:]:
-                skip_weight *= popped_die.total_weight()
+                skip_weight *= popped_die.denominator()
                 skip_weight += weight
             skip_weight *= math.prod(popped_die.weight_le(max_outcome) for max_outcome in max_outcomes[:num_unused_dice])
             pool = _pool_cached_unchecked(popped_die, count_dice=())
@@ -444,7 +473,7 @@ class DicePool():
             # We empty the rest of the pool immediately since no more dice can contribute counts.
             skip_weight = 0
             for weight in comb_row[end_counted:]:
-                skip_weight *= popped_die.total_weight()
+                skip_weight *= popped_die.denominator()
                 skip_weight += weight
             skip_weight *= math.prod(popped_die.weight_ge(min_outcome) for min_outcome in min_outcomes[num_possible_dice:])
             pool = _pool_cached_unchecked(popped_die, count_dice=())
@@ -491,7 +520,8 @@ class DicePool():
         
         Args:
             func: This can be an `EvalPool`, in which case it evaluates the pool directly.
-                Or it can be a `next_state()`-like function, taking in state, outcome, *counts and returning the next state.
+                Or it can be a `EvalPool.next_state()`-like function,
+                taking in `state, outcome, *counts` and returning the next state.
                 In this case a temporary `WrapFuncEval` is constructed and used to evaluate this pool.
         """
         if not isinstance(eval_or_func, hdroller.EvalPool):
